indexing

	description: "Class that combines two hash table into a new token file with probabilities."

	author: "Berend de Boer"
	copyright: "(c) 2003, Eiffel Forum License v2, see forum.txt"


class

	PROBABILITY


inherit

	ANY

	KL_SHARED_STANDARD_FILES
		export
			{NONE} all
		end

	EXCEPTIONS
		export
			{NONE} all
		end


creation

	make,
	make_default


feature {NONE} -- Initialization

	make is
		do
			std.output.put_string ("emc probability 0.2  (c) 2003 by Berend de Boer.%N")
			std.output.put_string ("Starting with header probabilities...%N")
			read_and_combine (spam_file_head, nonspam_file_head, "probability_head.txt")
			std.output.put_string ("Starting with body probabilities...%N")
			read_and_combine (spam_file_body, nonspam_file_body, "probability_body.txt")
			std.output.put_string ("finished.%N")
		end


feature -- Read files

	read_and_combine (a_spam_tokens, a_nonspam_tokens, an_output_file_name: STRING) is
			-- Read a file with spam and with nonspam tokens and combine
			-- them into a single probability file.
		require
			a_spam_tokens_not_empty: a_spam_tokens /= Void and then not a_spam_tokens.is_empty
			a_nonspam_tokens_not_empty: a_nonspam_tokens /= Void and then not a_nonspam_tokens.is_empty
			an_output_file_name_not_empty: an_output_file_name /= Void and then not an_output_file_name.is_empty
		local
			spam_table: TOKEN_TABLE
			nonspam_table: TOKEN_TABLE
			combined_table: PG_PROBABILITY_TABLE
		do
			std.output.put_string ("reading spam tokens...%N")
			create spam_table.make_from_file (a_spam_tokens)
			std.output.put_string ("reading nonspam tokens...%N")
			create nonspam_table.make_from_file (a_nonspam_tokens)
			std.output.put_string ("create spam probability...%N")
			create combined_table.make_combine (spam_table, nonspam_table)
			std.output.put_string ("writing token file...%N")
			dump_probability_table (an_output_file_name, spam_table.message_count, nonspam_table.message_count, combined_table.tokens)
		end


feature -- Action

	dump_probability_table (
				a_file_name: STRING;
				spam_messages_count,
				nonspam_messages_count: INTEGER;
				a_table: DS_HASH_TABLE [TOKEN_PROBABILITY, STRING]) is
			-- Write `a_table' to `a_file_name'.
		require
			a_file_name_not_empty: a_file_name /= Void and then not a_file_name.is_empty
			spam_messages_count_positive: spam_messages_count > 0
			nonspam_messages_count: nonspam_messages_count > 0
			a_table_not_void: a_table /= Void
		local
			file: KL_TEXT_OUTPUT_FILE
			data_point: TOKEN_PROBABILITY
		do
			create file.make (a_file_name)
			file.open_write
			if file.is_open_write then
				-- First line is spam_messages_count and nonspam_messages_count
				file.put_string (spam_messages_count.out)
				file.put_character (' ')
				file.put_string (nonspam_messages_count.out)
				file.put_character ('%N')
				-- Second line is x, the number to be used when there are
				-- no data points.
				file.put_string (no_data_points_value (a_table).out)
				file.put_character ('%N')
				-- Third line is number of tokens
				file.put_string (a_table.count.out)
				file.put_character ('%N')
				-- Rest of lines are tokens
				from
					a_table.start
				until
					a_table.after
				loop
					data_point := a_table.item_for_iteration
					file.put_string (data_point.probability.out)
					file.put_character (' ')
					file.put_string (data_point.token)
					file.put_character (' ')
					file.put_string (data_point.bad_count.out)
					file.put_character (' ')
					file.put_string (data_point.good_count.out)
					file.put_character ('%N')
					a_table.forth
				end
				file.close
			else
				std.error.put_string ("Cannot create probability file ")
				std.error.put_string (a_file_name)
				std.error.put_string (".%N")
				die (1)
			end
		end


feature {NONE} -- Implementation

	spam_file_body: STRING is "spam_body.txt"
	spam_file_head: STRING is "spam_head.txt"

	nonspam_file_body: STRING is "nonspam_body.txt"
	nonspam_file_head: STRING is "nonspam_head.txt"

end
