
indexing

	description: "Defines schema for an XM_VALIDATING_PARSER."

class

	EMC_SCHEMA


inherit

	ANY

	XM_DATA_FACTORY
		export
			{NONE} all
		end


feature -- Schema loading

	build_schema (vp: XM_VALIDATING_PARSER) is
			-- Make schema in `vp' equal to schema defined in this class.
		require
			vp_not_void: vp /= Void
		do
			vp.wipe_out_schema
			vp.add_element (emc)
			vp.add_element (server)
			vp.add_element (host)
			vp.add_element (port)
			vp.add_element (secure)
			vp.add_element (login_name)
			vp.add_element (password)
			vp.add_element (scan)
			vp.add_element (spam)
			vp.add_element (nonspam)
			vp.add_element (classify)
			vp.add_element (move_nonspam_to)
			vp.add_element (move_spam_to)
			vp.add_element (delete_spam)
			vp.add_element (message)
			vp.add_element (size)
			vp.add_element (threshold)
			vp.add_element (strength)
			vp.add_element (lower_minimum_deviation)
			vp.add_element (upper_minimum_deviation)
			vp.add_element (new_word_spaminess)
			vp.add_element (mailbox)

		end

feature -- My schema

	emc: XM_DEFINED_ELEMENT_CHILDREN is
		local
			child_def_emc: XM_CHILD_DEFINITION_SEQ
			attribute_version: XM_DEFINED_ATTRIBUTE
			child_def_emc_2: XM_CHILD_DEFINITION_NAME
			child_def_emc_3: XM_CHILD_DEFINITION_NAME
			child_def_emc_4: XM_CHILD_DEFINITION_NAME
		once
			create Result.make_empty_ns ("http://www.pobox.com/~berend/emc/", "emc")
			create child_def_emc_2.make (server)
			create child_def_emc_3.make (scan)
			create child_def_emc_4.make (classify)
			create attribute_version.make ("version", False)
			attribute_version.set_data (new_integer_data)
  			attribute_version.data.set_constraint (positive_integer_check)
  
			create child_def_emc.make_from_array (<<child_def_emc_2, child_def_emc_3, child_def_emc_4>>)
			Result.set_child_definition (child_def_emc)
  			Result.add_attribute (attribute_version)
		end


	server: XM_DEFINED_ELEMENT_CHILDREN is
		local
			child_def_server: XM_CHILD_DEFINITION_SEQ
			child_def_server_1: XM_CHILD_DEFINITION_NAME
			child_def_server_2: XM_CHILD_DEFINITION_OCCURRENCE
			child_def_server_2_1: XM_CHILD_DEFINITION_NAME
			child_def_server_3: XM_CHILD_DEFINITION_OCCURRENCE
			child_def_server_3_1: XM_CHILD_DEFINITION_NAME
			child_def_server_4: XM_CHILD_DEFINITION_NAME
			child_def_server_5: XM_CHILD_DEFINITION_OCCURRENCE
			child_def_server_5_1: XM_CHILD_DEFINITION_NAME
		once
			create Result.make_empty_ns ("http://www.pobox.com/~berend/emc/", "server")
			create child_def_server_1.make (host)
			create child_def_server_2_1.make (port)
			create child_def_server_2.make (child_def_server_2_1, 0, 1)
			create child_def_server_3_1.make (secure)
			create child_def_server_3.make (child_def_server_3_1, 0, 1)
			create child_def_server_4.make (login_name)
			create child_def_server_5_1.make (password)
			create child_def_server_5.make (child_def_server_5_1, 0, 1)

			create child_def_server.make_from_array (<<child_def_server_1, child_def_server_2, child_def_server_3, child_def_server_4, child_def_server_5>>)
			Result.set_child_definition (child_def_server)
  		end


	host: XM_DEFINED_ELEMENT_TEXT is
		once
			create Result.make_ns ("http://www.pobox.com/~berend/emc/", "host")
			Result.set_data (new_string_data)
  			Result.data.set_constraint (new_string_length_check (1, 2147483647))
  		end


	port: XM_DEFINED_ELEMENT_TEXT is
		once
			create Result.make_ns ("http://www.pobox.com/~berend/emc/", "port")
			Result.set_data (new_integer_data)
  			Result.data.set_constraint (new_integer_range_check (1, 65535))
  		end


	secure: XM_DEFINED_ELEMENT_TEXT is
		once
			create Result.make_ns ("http://www.pobox.com/~berend/emc/", "secure")
			Result.set_data (new_boolean_data)
  		end


	login_name: XM_DEFINED_ELEMENT_TEXT is
		once
			create Result.make_ns ("http://www.pobox.com/~berend/emc/", "login-name")
			Result.set_data (new_string_data)
  			Result.data.set_constraint (new_string_length_check (1, 2147483647))
  		end


	password: XM_DEFINED_ELEMENT_TEXT is
		once
			create Result.make_ns ("http://www.pobox.com/~berend/emc/", "password")
			Result.set_data (new_string_data)
  		end


	scan: XM_DEFINED_ELEMENT_CHILDREN is
		local
			child_def_scan: XM_CHILD_DEFINITION_SEQ
			attribute_minimum_occurrences: XM_DEFINED_ATTRIBUTE
			child_def_scan_2: XM_CHILD_DEFINITION_NAME
			child_def_scan_3: XM_CHILD_DEFINITION_NAME
		once
			create Result.make_empty_ns ("http://www.pobox.com/~berend/emc/", "scan")
			create child_def_scan_2.make (spam)
			create child_def_scan_3.make (nonspam)
			create attribute_minimum_occurrences.make ("minimum-occurrences", False)
			attribute_minimum_occurrences.set_data (new_integer_data)
  			attribute_minimum_occurrences.data.set_constraint (positive_integer_check)
  
			create child_def_scan.make_from_array (<<child_def_scan_2, child_def_scan_3>>)
			Result.set_child_definition (child_def_scan)
  			Result.add_attribute (attribute_minimum_occurrences)
		end


	spam: XM_DEFINED_ELEMENT_CHILDREN is
		local
			child_def_spam: XM_CHILD_DEFINITION_SEQ
			attribute_max_messages: XM_DEFINED_ATTRIBUTE
			attribute_max_message_size: XM_DEFINED_ATTRIBUTE
			child_def_spam_3: XM_CHILD_DEFINITION_OCCURRENCE

			child_def_spam_3_1: XM_CHILD_DEFINITION_NAME
		once
			create Result.make_empty_ns ("http://www.pobox.com/~berend/emc/", "spam")
			create child_def_spam_3_1.make (mailbox)
			create child_def_spam_3.make (child_def_spam_3_1, 1, 2147483647)
			create attribute_max_messages.make ("max-messages", False)
			attribute_max_messages.set_data (new_integer_data)
  			attribute_max_messages.data.set_constraint (positive_integer_check)
  			create attribute_max_message_size.make ("max-message-size", False)
			attribute_max_message_size.set_data (new_integer_data)
  			attribute_max_message_size.data.set_constraint (non_negative_integer_check)
  
			create child_def_spam.make_from_array (<<child_def_spam_3>>)
			Result.set_child_definition (child_def_spam)
  			Result.add_attribute (attribute_max_messages)
			Result.add_attribute (attribute_max_message_size)
		end


	nonspam: XM_DEFINED_ELEMENT_CHILDREN is
		local
			child_def_nonspam: XM_CHILD_DEFINITION_SEQ
			attribute_max_messages: XM_DEFINED_ATTRIBUTE
			attribute_max_message_size: XM_DEFINED_ATTRIBUTE
			child_def_nonspam_3: XM_CHILD_DEFINITION_OCCURRENCE

			child_def_nonspam_3_1: XM_CHILD_DEFINITION_NAME
		once
			create Result.make_empty_ns ("http://www.pobox.com/~berend/emc/", "nonspam")
			create child_def_nonspam_3_1.make (mailbox)
			create child_def_nonspam_3.make (child_def_nonspam_3_1, 1, 2147483647)
			create attribute_max_messages.make ("max-messages", False)
			attribute_max_messages.set_data (new_integer_data)
  			attribute_max_messages.data.set_constraint (positive_integer_check)
  			create attribute_max_message_size.make ("max-message-size", False)
			attribute_max_message_size.set_data (new_integer_data)
  			attribute_max_message_size.data.set_constraint (non_negative_integer_check)
  
			create child_def_nonspam.make_from_array (<<child_def_nonspam_3>>)
			Result.set_child_definition (child_def_nonspam)
  			Result.add_attribute (attribute_max_messages)
			Result.add_attribute (attribute_max_message_size)
		end


	classify: XM_DEFINED_ELEMENT_CHILDREN is
		local
			child_def_classify: XM_CHILD_DEFINITION_SEQ

			child_def_classify_1: XM_CHILD_DEFINITION_NAME
			child_def_classify_2: XM_CHILD_DEFINITION_OCCURRENCE
			child_def_classify_2_1: XM_CHILD_DEFINITION_NAME
			child_def_classify_3: XM_CHILD_DEFINITION_OCCURRENCE
			child_def_classify_3_1: XM_CHILD_DEFINITION_NAME
			child_def_classify_4: XM_CHILD_DEFINITION_OCCURRENCE
			child_def_classify_4_1: XM_CHILD_DEFINITION_NAME
			child_def_classify_5: XM_CHILD_DEFINITION_NAME
			child_def_classify_6: XM_CHILD_DEFINITION_OCCURRENCE
			child_def_classify_6_1: XM_CHILD_DEFINITION_NAME
			child_def_classify_7: XM_CHILD_DEFINITION_OCCURRENCE
			child_def_classify_7_1: XM_CHILD_DEFINITION_NAME
			child_def_classify_8: XM_CHILD_DEFINITION_OCCURRENCE
			child_def_classify_8_1: XM_CHILD_DEFINITION_NAME
			child_def_classify_9: XM_CHILD_DEFINITION_OCCURRENCE
			child_def_classify_9_1: XM_CHILD_DEFINITION_NAME
		once
			create Result.make_empty_ns ("http://www.pobox.com/~berend/emc/", "classify")
			create child_def_classify_1.make (mailbox)
			create child_def_classify_2_1.make (move_nonspam_to)
			create child_def_classify_2.make (child_def_classify_2_1, 0, 1)
			create child_def_classify_3_1.make (move_spam_to)
			create child_def_classify_3.make (child_def_classify_3_1, 0, 1)
			create child_def_classify_4_1.make (delete_spam)
			create child_def_classify_4.make (child_def_classify_4_1, 0, 1)
			create child_def_classify_5.make (threshold)
			create child_def_classify_6_1.make (strength)
			create child_def_classify_6.make (child_def_classify_6_1, 0, 1)
			create child_def_classify_7_1.make (lower_minimum_deviation)
			create child_def_classify_7.make (child_def_classify_7_1, 0, 1)
			create child_def_classify_8_1.make (upper_minimum_deviation)
			create child_def_classify_8.make (child_def_classify_8_1, 0, 1)
			create child_def_classify_9_1.make (new_word_spaminess)
			create child_def_classify_9.make (child_def_classify_9_1, 0, 1)

			create child_def_classify.make_from_array (<<child_def_classify_1, child_def_classify_2, child_def_classify_3, child_def_classify_4, child_def_classify_5, child_def_classify_6, child_def_classify_7, child_def_classify_8, child_def_classify_9>>)
			Result.set_child_definition (child_def_classify)
  		end


	move_nonspam_to: XM_DEFINED_ELEMENT_TEXT is
		once
			create Result.make_ns ("http://www.pobox.com/~berend/emc/", "move-nonspam-to")
			Result.set_data (new_string_data)
  		end


	move_spam_to: XM_DEFINED_ELEMENT_TEXT is
		once
			create Result.make_ns ("http://www.pobox.com/~berend/emc/", "move-spam-to")
			Result.set_data (new_string_data)
  		end


	delete_spam: XM_DEFINED_ELEMENT_CHILDREN is
		local
			child_def_delete_spam: XM_CHILD_DEFINITION_SEQ
			child_def_delete_spam_1: XM_CHILD_DEFINITION_NAME
		once
			create Result.make_empty_ns ("http://www.pobox.com/~berend/emc/", "delete-spam")
			create child_def_delete_spam_1.make (message)

			create child_def_delete_spam.make_from_array (<<child_def_delete_spam_1>>)
			Result.set_child_definition (child_def_delete_spam)
  		end


	message: XM_DEFINED_ELEMENT_CHILDREN is
		local
			child_def_message: XM_CHILD_DEFINITION_SEQ
			child_def_message_1: XM_CHILD_DEFINITION_NAME
		once
			create Result.make_empty_ns ("http://www.pobox.com/~berend/emc/", "message")
			create child_def_message_1.make (size)

			create child_def_message.make_from_array (<<child_def_message_1>>)
			Result.set_child_definition (child_def_message)
  		end


	size: XM_DEFINED_ELEMENT_TEXT is
		once
			create Result.make_ns ("http://www.pobox.com/~berend/emc/", "size")
			Result.set_data (new_integer_data)
  			Result.data.set_constraint (non_negative_integer_check)
  		end


	threshold: XM_DEFINED_ELEMENT_TEXT is
		once
			create Result.make_ns ("http://www.pobox.com/~berend/emc/", "threshold")
			Result.set_data (new_double_data)
  			Result.data.set_constraint (new_double_range_check (-1, True, 1, True))
  		end


	strength: XM_DEFINED_ELEMENT_TEXT is
		once
			create Result.make_ns ("http://www.pobox.com/~berend/emc/", "strength")
			Result.set_data (new_double_data)
  			Result.data.set_constraint (new_double_range_check (0, True, 1, True))
  		end


	lower_minimum_deviation: XM_DEFINED_ELEMENT_TEXT is
		once
			create Result.make_ns ("http://www.pobox.com/~berend/emc/", "lower-minimum-deviation")
			Result.set_data (new_double_data)
  			Result.data.set_constraint (new_double_range_check (-1, True, 1, True))
  		end


	upper_minimum_deviation: XM_DEFINED_ELEMENT_TEXT is
		once
			create Result.make_ns ("http://www.pobox.com/~berend/emc/", "upper-minimum-deviation")
			Result.set_data (new_double_data)
  			Result.data.set_constraint (new_double_range_check (-1, True, 1, True))
  		end


	new_word_spaminess: XM_DEFINED_ELEMENT_TEXT is
		once
			create Result.make_ns ("http://www.pobox.com/~berend/emc/", "new-word-spaminess")
			Result.set_data (new_double_data)
  			Result.data.set_constraint (new_double_range_check (-1, True, 1, True))
  		end


	mailbox: XM_DEFINED_ELEMENT_TEXT is
		local
			attribute_max_messages: XM_DEFINED_ATTRIBUTE
			attribute_max_message_size: XM_DEFINED_ATTRIBUTE
			attribute_percentage: XM_DEFINED_ATTRIBUTE
			attribute_lowest_sequence: XM_DEFINED_ATTRIBUTE
			attribute_highest_sequence: XM_DEFINED_ATTRIBUTE
		once
			create attribute_max_messages.make ("max-messages", False)
			attribute_max_messages.set_data (new_integer_data)
  			attribute_max_messages.data.set_constraint (non_negative_integer_check)
  			create attribute_max_message_size.make ("max-message-size", False)
			attribute_max_message_size.set_data (new_integer_data)
  			attribute_max_message_size.data.set_constraint (non_negative_integer_check)
  			create attribute_percentage.make ("percentage", False)
			attribute_percentage.set_data (new_integer_data)
  			attribute_percentage.data.set_constraint (positive_integer_check)
  			create attribute_lowest_sequence.make ("lowest-sequence", False)
			attribute_lowest_sequence.set_data (new_integer_data)
  			attribute_lowest_sequence.data.set_constraint (positive_integer_check)
  			create attribute_highest_sequence.make ("highest-sequence", False)
			attribute_highest_sequence.set_data (new_integer_data)
  			attribute_highest_sequence.data.set_constraint (positive_integer_check)
  			create Result.make_ns ("http://www.pobox.com/~berend/emc/", "mailbox")
			Result.set_data (new_string_data)
  			Result.data.set_constraint (new_string_length_check (1, 2147483647))
  			Result.add_attribute (attribute_max_messages)
			Result.add_attribute (attribute_max_message_size)
			Result.add_attribute (attribute_percentage)
			Result.add_attribute (attribute_lowest_sequence)
			Result.add_attribute (attribute_highest_sequence)
		end



end
