indexing

	description: "Produces tokens from character input."

	author: "Berend de Boer"


class

	TOKEN_WRITER


inherit

	PW_DRAIN_WRITER [CHARACTER]
		redefine
			drain,
			flush,
			make,
			put
		end


creation

	make


feature {NONE} -- Initialization

	make is
		do
			precursor
			if token = Void then
				create token.make (token_limit)
			end
		end


feature -- Connection management

	drain: PW_WRITER [STRING]


feature -- Writing

	flush is
			-- Empty any buffered items.
		do
			write_token
		end

	put (item: CHARACTER) is
			-- Create tokens from `item', and if a token has been
			-- formed, write it to `drain'.
		do
			if item.code <= 32 then
				-- Any control character or space is considered a token separator.
				write_token
			else
				inspect item
				when '<', '>', '!', '?', '_', '/', '&', '(', ')', '{', '}' then
					-- These tokens always separate words.
					-- When I have real HTML parsing, I can become smarter
					-- about this.
					write_token
				else
					-- Else just append characters and '.' and such.
					-- Will be cleaned up by `write_token'.
					token.append_character (item)
				end
			end
-- 			inspect item
-- 			when 'A'..'Z', 'a'..'z', '0'..'9' then
-- 				if not token.is_empty and then token.item (token.count) = '!' then
-- 					write_token
-- 					token.wipe_out
-- 				end
-- 				token.append_character (item)
-- 			when '!' then
-- 				-- Consider ! marks as separate tokens
-- 				if not token.is_empty and then token.item (token.count) /= '!' then
-- 					write_token
-- 					token.wipe_out
-- 				end
-- 				token.append_character (item)
-- 			when '<' then
-- 				if token.is_empty then
-- 					token.append_character (item)
-- 				end
-- 			else
-- 				write_token
-- 				token.wipe_out
-- 			end
		end


feature {NONE} -- Implementation

	token: STRING

	token_limit: INTEGER is 64
			-- Maximum length of tokens that will be written.

	do_write_token is
			-- Put `token' in `drain'.
		require
			not_empty: not token.is_empty
			token_has_no_white_space: not token.has (' ') and then not token.has ('%T')
		local
			lower_token: STRING
		do
			-- write only the first 64 characters
			if token.count > token_limit then
				token.keep_head (token_limit)
			end
			-- Write only the lowercase variant.
			-- Changing case isn't important for humans, so it
			-- shouldn't be important for a classifier.
			lower_token := token.as_lower
			drain.put (lower_token)
			copy_error_from_drain
		end

	write_token is
			-- Write `token' if it has more than 1 character.
		local
			i: INTEGER
		do
			if token.count > 1 then
				-- Remove non-letters from token.
				from
					i := 1
				variant
					token.count - (i - 1)
				until
					i > token.count
				loop
					-- What about words as traveler's, who's, they'll?
					-- i.e. the 's at end$ English specific perhaps.
					-- Subjects start with re: and fwd:, they're now joined.
					-- So you get re:status, re:auto-dialer, etc.
					-- Should split this off.
					inspect token.item (i)
					when '.', ',', ';', '*', '-', '"', '%'', '`' then
						token.remove (i)
					when ':' then
						-- Keep "::" as it is used in code.
						if
							i = token.count or else
							token.item (i + 1) /= ':'
						then
							token.remove (i)
						else
							i := i + 2
						end
					else
						i := i + 1
					end
				end
				if token.count > 1 then
					do_write_token
				end
			end
			token.wipe_out
		ensure
			token_empty: token.is_empty
		end

invariant

	token_not_void: token /= Void

end
